package HSPC::GeoData;

use HSPC::Config;
use HSPC::Localization;
use SWsoft::protect;

our $VERSION = '0.1';

use strict;
use vars qw(@ISA @EXPORT &get_countries &get_states_us &get_states_ca);
@ISA = qw(Exporter);
@EXPORT = qw(&get_countries &get_states_us &get_states_ca);

use constant COUNTRY_IDS=>qw(AF AL DZ AS AD AO AI AQ AG AR AM AW AU AT AZ BS BH BD BB BY BE BZ BJ BM BT BO BA BW BV BR IO BN BG BF BI KH CM CA CV KY CF TD CL CN CX CC CO KM CG CK CR CI HR CU CY CZ DK DJ DM DO TP EC EG SV GQ ER EE ET FK FO FJ FI FR FX GF PF TF GA GM GEDE GH GI GR GL GD GP GU GT GG GN GW GY HT HM HN HK HU IS IN ID IR IQ IE IM IL IT JM JP JE JO KZ KE KI KR KP KW KG LA LV LB LS LR LY LI LT LU MO MK MG MW MY MV ML MT MH MQ MR MU YT MX FM MD MC MN MS MA MZ MM NA NR NP NL AN NC NZ NI NE NG NUNF MP NO OM PK PW PS PA PG PY PE PH PN PL PT PR QA RE RO RU RW SH KN LC PM VC WS SM ST SA SN SC SL SG SK SI SB SO ZA GS ES LK SD SR SJ SZ SE CH SY TW TJ TZ TH TG TK TO TT TN TR TM TC TV UG UA AE GB US UM UY UZ VU VA VE VN VI VG WF EH YE YU CD ZM ZW);

use constant STATE_US_IDS=>qw(AL AK AS AZ AR AE AA AP CA CO CT DE DC FM FL GA GU HI ID IL IN IA KS KY LA ME MH MD MA MI MN MS MO MT NE NV NH NJ NM NY NC ND MP OH OK OR PW PA PR RI SC SD TN TX TT UT VT VI VA WA WV WI WY);

use constant STATE_CA_IDS=>qw(AB BC MB NB NF NT NS NU ON PE QC SK YT);

sub get_countries{	
	return get_countries_lang($LOCALE{local_lang});       
}

# > lang_id : REQ
sub get_countries_lang{
	my $lang_id = shift;    
	my $c = HSPC::Localization::get_countries_lang($lang_id);
	return $c if ( scalar(@{$c}) );
	## no lang packages installed
	return [ map [$_,$_], COUNTRY_IDS ];
};

sub get_states_us{	
	return get_states_us_lang($LOCALE{local_lang});       
}

sub get_states_ca{	
	return get_states_ca_lang($LOCALE{local_lang});
}

# > lang_id : REQ
sub get_states_us_lang{
	my $lang_id = shift;    	
	my $s = HSPC::Localization::get_states_us_lang($lang_id);
	return $s if ( scalar(@{$s}) );
	## no lang packages installed
	return [ map [$_,$_], STATE_US_IDS ];
};

# > lang_id : REQ
sub get_states_ca_lang{
	my $lang_id = shift;    	
	my $s = HSPC::Localization::get_states_ca_lang($lang_id);
	return $s if ( scalar(@{$s}) );
	## no lang packages installed
	return [ map [$_,$_], STATE_CA_IDS ];
};

sub get_states{
	my $list;
	push @$list,['', HSPC::Localization::string('state_dd')];
	push @$list,@{get_states_us()};
	push @$list,['-', HSPC::Localization::string('province_dd')];
	push @$list,@{get_states_ca()};
	return $list;
}

# > country_id
sub get_country_name{
	my $country_id = shift;	
	my $countries = get_countries();
	
	foreach my $country(@$countries){
		return $country->[1] if $country->[0] eq $country_id;
	}
	return undef;	
}

# > country_id
# > state_id
sub get_state_name{
	my $country_id = shift;	
	my $state_id = shift;	
	my $states;
	$states = get_states_us() if $country_id eq 'US';
	$states = get_states_ca() if $country_id eq 'CA';
	
	foreach my $state(@$states){
		return $state->[1] if $state->[0] eq $state_id;
	}
	return undef;
}

1;
